==> customer-space-parent-1.4.8-source-release.zip: customer-space-parent-1.4.8/portlet/src/main/webapp/vue-app/ticketMenu/initComponents.js <==
import TicketMenu from './components/TicketMenu.vue';
import CSEnvironment from './components/CSEnvironment.vue';
import CSTicketRate from './components/CSTicketRate.vue';
import StickyMiniTicketMenu from './components/StickyMiniTicketMenu.vue';
import TicketAttachedTasks from './components/TicketAttachedTasks.vue';
import TicketSeverities from './components/TicketSeverities.vue';
import TicketStatuses from './components/TicketStatuses.vue';
import TicketEditModeAction from './components/TicketEditModeAction.vue';
import TicketStatusReason from './components/TicketStatusReason.vue';
import TicketQuickAccessActions from './components/TicketQuickAccessActions.vue';


import * as ticketService from '../services/TicketService.js';
import * as csInfoService from '../services/CSInfoService.js';
import * as csService from '../services/CSService.js';
import * as csUtils from '../services/Utils.js';

const components = {
  'cs-ticket-menu': TicketMenu,
  'cs-environment': CSEnvironment,
  'cs-ticket-rate': CSTicketRate,
  'cs-sticky-mini-ticket-menu': StickyMiniTicketMenu,
  'cs-ticket-attached-tasks': TicketAttachedTasks,
  'cs-ticket-severities': TicketSeverities,
  'cs-ticket-statuses': TicketStatuses,
  'cs-ticket-edit-mode-action': TicketEditModeAction,
  'cs-ticket-status-reason': TicketStatusReason,
  'cs-ticket-quick-access-actions': TicketQuickAccessActions
};

for (const key in components) {
  Vue.component(key, components[key]);
}

if (!Vue.prototype.$ticketService) {
  window.Object.defineProperty(Vue.prototype, '$ticketService', {
    value: ticketService,
  });
}
if (!Vue.prototype.$csInfoService) {
  window.Object.defineProperty(Vue.prototype, '$csInfoService', {
    value: csInfoService,
  });
}
if (!Vue.prototype.$csService) {
  window.Object.defineProperty(Vue.prototype, '$csService', {
    value: csService,
  });
}
if (!Vue.prototype.$csUtils) {
  window.Object.defineProperty(Vue.prototype, '$csUtils', {
    value: csUtils,
  });
}

==> customer-space-parent-1.5.1-source-release.zip: customer-space-parent-1.5.1/portlet/src/main/webapp/vue-app/ticketMenu/initComponents.js <==
import TicketMenu from './components/TicketMenu.vue';
import CSEnvironment from './components/CSEnvironment.vue';
import CSTicketRate from './components/CSTicketRate.vue';
import StickyMiniTicketMenu from './components/StickyMiniTicketMenu.vue';
import TicketAttachedTasks from './components/ticketMenuComponents/TicketAttachedTasks.vue';
import TicketSeverities from './components/ticketMenuComponents/TicketSeverities.vue';
import TicketStatuses from './components/ticketMenuComponents/TicketStatuses.vue';
import TicketEditModeAction from './components/TicketEditModeAction.vue';
import TicketStatusReason from './components/ticketMenuComponents/TicketStatusReason.vue';
import TicketQuickAccessActions from './components/ticketMenuComponents/TicketQuickAccessActions.vue';


import * as csInfoService from '../services/CSInfoService.js';

const components = {
  'cs-ticket-menu': TicketMenu,
  'cs-environment': CSEnvironment,
  'cs-ticket-rate': CSTicketRate,
  'cs-sticky-mini-ticket-menu': StickyMiniTicketMenu,
  'cs-ticket-attached-tasks': TicketAttachedTasks,
  'cs-ticket-severities': TicketSeverities,
  'cs-ticket-statuses': TicketStatuses,
  'cs-ticket-edit-mode-action': TicketEditModeAction,
  'cs-ticket-status-reason': TicketStatusReason,
  'cs-ticket-quick-access-actions': TicketQuickAccessActions
};

for (const key in components) {
  Vue.component(key, components[key]);
}

if (!Vue.prototype.$csInfoService) {
  window.Object.defineProperty(Vue.prototype, '$csInfoService', {
    value: csInfoService,
  });
}
